componenttools.copy_governed_component_subtree_from_prolated_offset_to
======================================================================

.. autofunction:: abjad.tools.componenttools.copy_governed_component_subtree_from_prolated_offset_to.copy_governed_component_subtree_from_prolated_offset_to
